﻿local FSwapper3 = LibStub("AceAddon-3.0"):GetAddon("FSwapper3");
local L = LibStub("AceLocale-3.0"):GetLocale("FSwapper3", true);

local FS3GUI = FSwapper3.FS3GUI;
local EquipList;

local TabFrame = FS3GUI.TabFrame;
local WeaponFrame = FS3GUI.SubFrame[1];
local OptionsFrame = FS3GUI.SubFrame[2];
local AutoLootFrame = FS3GUI.SubFrame[3];
local EquipmentFrame = FS3GUI.SubFrame[4];

function EquipmentFrame:DoInit()
	EquipmentFrame.DidInit = true;
	
	EquipmentFrame:SetFrameStrata("DIALOG");
	EquipmentFrame:SetWidth(FS3GUI.Width);
	EquipmentFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile = true, tileSize = 32, edgeSize = 32, 
			insets = { left = 8, right = 8, top = 8, bottom = 8 }
		});
	EquipmentFrame:SetBackdropColor(0,0,0,1);
	EquipmentFrame:EnableMouse();
	EquipmentFrame:SetPoint("TOPLEFT", TabFrame, "BOTTOMLEFT", 0, 12);
	
	EquipmentFrame.Instructions = EquipmentFrame:CreateFontString("$parent_Instructions","ARTWORK","GameFontNormal");
	EquipmentFrame.Instructions:SetJustifyH("LEFT");
	EquipmentFrame.Instructions:SetJustifyV("TOP");
	EquipmentFrame.Instructions:SetPoint("TOPLEFT", EquipmentFrame, "TOPLEFT", 13, -13);
	EquipmentFrame.Instructions:SetText(L["Drag items to the slot below to use them with \"/fswapper3 gofish\" (in a macro) or by clicking the Data Broker object. The item previously worn will be restored with \"/fswapper3 gofight\" or by clicking the Data Broker object again."]
										.. "|n|n" ..
										L["Right clicking the items below will clear the slot and prevent swapping."]);
	EquipmentFrame.Instructions:SetWidth(FS3GUI.Width - 26);
	EquipmentFrame.Instructions:SetTextColor(0.2235, 0.6549, 0.8745);
	
	EquipmentFrame.SlotList = {};
	EquipmentFrame.SlotList.ypos = 18 + EquipmentFrame.Instructions:GetHeight();
	
	EquipList = FSwapper3.db.char.Equipment;
	for i, v in ipairs(EquipList) do
		EquipmentFrame:AddSlot(EquipmentFrame.SlotList, i);
	end
	
	EquipmentFrame:SetHeight(EquipmentFrame.SlotList.ypos + 13);
end

function EquipmentFrame:AddSlot(list, slotindex)
	local index = (#list) + 1;
	local maxwidth = FS3GUI.Width - 26;
	
	local SlotLine = {};
	local data = EquipList[slotindex];
	SlotLine.Slot = data.Slot;
	SlotLine.EquipLoc = data.EquipLoc;
	
	SlotLine.Label = EquipmentFrame:CreateFontString("$parent_SlotLabel" .. index,"ARTWORK","GameFontNormal");
	SlotLine.Label:SetText(data.Name .. ": ");
	SlotLine.Label:SetPoint("TOPLEFT", EquipmentFrame, "TOPLEFT", 13, -(list.ypos));
	SlotLine.Label:SetJustifyH("LEFT");
	SlotLine.Label:SetJustifyV("MIDDLE");
	SlotLine.Label:SetHeight(37);
	
	SlotLine.Button = CreateFrame("Button", nil, EquipmentFrame);
	SlotLine.Button:SetPoint("TOPLEFT", SlotLine.Label, "TOPRIGHT");
	SlotLine.Button:SetWidth(37);
	SlotLine.Button:SetHeight(37);
	SlotLine.Button:EnableMouse();
	SlotLine.Button:RegisterForClicks("LeftButtonUp", "RightButtonUp");
	SlotLine.Button:RegisterForDrag("LeftButton");
	
	SlotLine.Button:SetScript("OnReceiveDrag", function(self, button)
			local itemtype, link, _;
			itemtype, _, link = GetCursorInfo();
			if (itemtype == "item") then
				if (SlotLine.EquipLoc == (select(9, GetItemInfo(link)))) then
					ClearCursor();
					EquipList[slotindex].Fishing = link;
					EquipmentFrame:DoUpdate();
				end
			end
		end);
	SlotLine.Button:SetScript("OnClick", function(self, button)
			if (button == "LeftButton") then
				local itemtype, link, _;
				itemtype, _, link = GetCursorInfo();
				if (itemtype == "item") then
					if (SlotLine.EquipLoc == (select(9, GetItemInfo(link)))) then
						ClearCursor();
						EquipList[slotindex].Fishing = link;
						EquipmentFrame:DoUpdate();
					end
				end
			elseif (button == "RightButton") then
				EquipList[index].Enable = false;
				EquipList[index].Fishing = nil;
				EquipmentFrame:DoUpdate();
			end
		end);
	SlotLine.Button:SetScript("OnEnter", function()
			GameTooltip:SetOwner(SlotLine.Button, "ANCHOR_NONE");
			GameTooltip:SetPoint("TOPLEFT", SlotLine.Button, "TOPRIGHT");
			GameTooltip:ClearLines();
			if (EquipList[index].Fishing) then
				GameTooltip:SetHyperlink(EquipList[slotindex].Fishing);
			else
				GameTooltip:AddLine(L["|cffff0000[Not Set]|r"]);
			end
			GameTooltip:Show();
		end);
	SlotLine.Button:SetScript("OnLeave", function()
			GameTooltip:Hide();
		end);
		
	list.ypos = list.ypos + SlotLine.Button:GetHeight() + 5;
	
	list[index] = SlotLine;
end

function EquipmentFrame:DoUpdate()
	for i, v in ipairs(EquipmentFrame.SlotList) do
		if (EquipList[i].Fishing) then
			v.Button:SetNormalTexture(GetItemIcon(EquipList[i].Fishing));
		else
			v.Button:SetNormalTexture(select(2, GetInventorySlotInfo(v.Slot)));
		end
	end
end