﻿local FSwapper3 = LibStub("AceAddon-3.0"):GetAddon("FSwapper3");
local L = LibStub("AceLocale-3.0"):GetLocale("FSwapper3", true);

local FS3GUI = FSwapper3.FS3GUI;

local TabFrame = FS3GUI.TabFrame;
local WeaponFrame = FS3GUI.SubFrame[1];
local OptionsFrame = FS3GUI.SubFrame[2];
local AutoLootFrame = FS3GUI.SubFrame[3];
local EquipmentFrame = FS3GUI.SubFrame[4];

function WeaponFrame:DoInit()
	WeaponFrame.DidInit = true;
	
	WeaponFrame:SetFrameStrata("DIALOG");
	WeaponFrame:SetWidth(FS3GUI.Width);
	WeaponFrame:SetBackdrop({
			bgFile="Interface\\DialogFrame\\UI-DialogBox-Background",
			edgeFile="Interface\\DialogFrame\\UI-DialogBox-Border", 
			tile = true, tileSize = 32, edgeSize = 32, 
			insets = { left = 8, right = 8, top = 8, bottom = 8 }
		});
	WeaponFrame:SetBackdropColor(0,0,0,1);
	WeaponFrame:EnableMouse();
	WeaponFrame:SetPoint("TOPLEFT", TabFrame, "BOTTOMLEFT", 0, 12);
	
	WeaponFrame.Instructions = WeaponFrame:CreateFontString("$parent_Instructions","ARTWORK","GameFontNormal");
	WeaponFrame.Instructions:SetJustifyH("LEFT");
	WeaponFrame.Instructions:SetJustifyV("TOP");
	WeaponFrame.Instructions:SetPoint("TOPLEFT", WeaponFrame, "TOPLEFT", 13, -13);
	WeaponFrame.Instructions:SetText(L["The following items are set automatically, and are shown just to indicate what FSwapper3 believes your weapons are."]);
	WeaponFrame.Instructions:SetWidth(FS3GUI.Width - 26);
	WeaponFrame.Instructions:SetTextColor(0.2235, 0.6549, 0.8745);
	
	WeaponFrame.WeaponList = {};
	WeaponFrame:AddWeaponLine(WeaponFrame.WeaponList, MAINHANDSLOT .. ": ", "MainHand", (-18 - WeaponFrame.Instructions:GetHeight()));
	WeaponFrame:AddWeaponLine(WeaponFrame.WeaponList, SECONDARYHANDSLOT .. ": ", "OffHand");
	WeaponFrame:AddWeaponLine(WeaponFrame.WeaponList, FSwapper3.LFISHINGPOLES .. ": ", "Pole");
	
end

function WeaponFrame:AddWeaponLine(list, label, value, ypos)
	local index = (#list) + 1;
	
	local WpnLine = {};
	WpnLine.Value = value;
	
	WpnLine.Label = WeaponFrame:CreateFontString("$parent_WpnLabel" .. index, "ARTWORK", "GameFontNormal");
	WpnLine.Button = CreateFrame("Button", nil, WeaponFrame);
	
	if (ypos) then
		WpnLine.Label:SetPoint("TOPLEFT", WeaponFrame, "TOPLEFT", 13, ypos);
	else
		WpnLine.Label:SetPoint("TOPLEFT", list[index-1].Label, "BOTTOMLEFT", 0, -5);
	end
	WpnLine.Label:SetText(label);
	WpnLine.Label:SetJustifyH("LEFT");
	WpnLine.Label:SetJustifyV("MIDDLE");
	WpnLine.Label:SetHeight(37);
		
	WpnLine.Button:SetPoint("TOPLEFT", WpnLine.Label, "TOPRIGHT");
	WpnLine.Button:SetWidth(37);
	WpnLine.Button:SetHeight(37);
		
	WpnLine.Button:SetScript("OnEnter", function()
			GameTooltip:SetOwner(WpnLine.Button, "ANCHOR_NONE");
			GameTooltip:SetPoint("TOPLEFT", WpnLine.Button, "BOTTOMLEFT");
			GameTooltip:ClearLines();
			if (FSwapper3.db.char[value]) then
				GameTooltip:SetHyperlink(FSwapper3.db.char[value]);
			else
				GameTooltip:AddLine(L["|cffff0000[Not Set]|r"]);
			end
			GameTooltip:Show();
		end);
	WpnLine.Button:SetScript("OnLeave", function()
			GameTooltip:Hide();
		end);
		
	list[index] = WpnLine;
end

function WeaponFrame:DoUpdate()
	local frameheight = (18 + WeaponFrame.Instructions:GetHeight());
	for i, WpnLine in ipairs(WeaponFrame.WeaponList) do
		if (FSwapper3.db.char[WpnLine.Value]) then
			WpnLine.Button:SetNormalTexture(GetItemIcon(FSwapper3.db.char[WpnLine.Value]));
		else
			WpnLine.Button:SetNormalTexture(select(2, GetInventorySlotInfo("MAINHANDSLOT")));
		end

		frameheight = frameheight + WpnLine.Button:GetHeight() + 5;
	end
	frameheight = frameheight + 8;
	WeaponFrame:SetHeight(frameheight);
end